@@ -525,7 +525,6 @@ class KafkaClient(object):
     def _add_record(self, record, **kwargs):
         try:
 
-            print('filter timestamp %s, timestamp of Kafka record %s' % (kwargs.get('timestamp_from'), record.timestamp))
             if kwargs.get('timestamp_from') == 0 or kwargs.get('timestamp_from') <= record.timestamp:
 
                 record = {
@@ -538,8 +537,6 @@ class KafkaClient(object):
                 if record not in self._record_list:
                     self._record_list.append(record)
 
-                print('Kafka record inserted in list')
-
         except Exception as e:
             self._log.error(e)
 
